declare type RestFieldSettings = {
    /**
     * Select Value.
     * A function for selecting the value for this rest field.
     * This function is expected to select the value from custom wp/data store related to this field.
     */
    selectValue: () => unknown;
    /**
     * Connected stores.
     * We decided to build the admin with Single Page Application concept but there are various problems we faced.
     * One of which is in builder. Builder depends on wp data stores and the challenge was how to force
     * the (wp-data) stores to refresh their resolvers and re-calculate their resolved values within this SPA.
     * That's why this param is here. You specify with your rest field the connected stores to it and all of
     * the connected stores are gathered to have their resolution cache to be invalidated so it is like hard refresh for resolvers.
     * However, it isn't necessray to pass this param.
     *
     * @see https://developer.wordpress.org/block-editor/packages/packages-data/#resolvers
     */
    connectedStores?: string[];
};
/**
 * Defined behavior of a rest field.
 */
declare type RestFields = Record<string, RestFieldSettings>;
/**
 * Register rest fields
 *
 * @param {string} name     Rest field unique name. Must be unique.
 * @param {Object} settings Rest field settings.
 *
 * @example
 * registerRestField('rest-field-example', {
 *    getValue: (select) => select('my-example-store').myExampleSelector();
 * })
 */
export declare const registerRestField: (name: string, settings: RestFieldSettings) => RestFieldSettings | undefined;
/**
 * Returns a registered rest field settings.
 *
 * @param {string} name Rest field name.
 *
 */
export declare function getRestField(name: string): RestFieldSettings;
/**
 * Returns all registered rest fields.
 */
export declare function getRestFields(): RestFields;
export {};
//# sourceMappingURL=index.d.ts.map